PyCoordGeodetic
===============

.. currentmodule:: cysgp4

.. autoclass:: PyCoordGeodetic
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~PyCoordGeodetic.alt
      ~PyCoordGeodetic.ecef
      ~PyCoordGeodetic.lat
      ~PyCoordGeodetic.lon

   .. rubric:: Attributes Documentation

   .. autoattribute:: alt
   .. autoattribute:: ecef
   .. autoattribute:: lat
   .. autoattribute:: lon
